==> FreePastry-1.4.3_01_20060110-source.tgz: pastry-1.4.3_01_20060110/src/rice/pastry/routing/BroadcastRouteRow.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
package rice.pastry.routing;

import rice.pastry.*;
import rice.pastry.messaging.*;
import rice.pastry.security.*;

import java.util.*;
import java.io.*;

/**
 * Broadcast message for a row from a routing table.
 *
 * @version $Id: BroadcastRouteRow.java 2570 2005-06-09 21:54:10Z jeffh $
 * @author Andrew Ladd
 */

public class BroadcastRouteRow extends Message implements Serializable {
  private NodeHandle fromNode;

  private RouteSet[] row;

  private final static Address addr = new RouteProtocolAddress();

  /**
   * Constructor.
   *
   * @param cred the credentials
   * @param stamp the timestamp
   * @param from the node id
   * @param r the row
   */
  public BroadcastRouteRow(Credentials cred, Date stamp, NodeHandle from,
                           RouteSet[] r) {
    super(addr, cred, stamp);

    fromNode = from;
    row = r;
    setPriority(0);
  }

  /**
   * Constructor.
   *
   * @param stamp the timestamp
   * @param from the node id
   * @param r the row
   */
  public BroadcastRouteRow(Date stamp, NodeHandle from, RouteSet[] r) {
    super(addr, stamp);

    fromNode = from;
    row = r;
    setPriority(0);
  }

  /**
   * Constructor.
   *
   * @param cred the credentials
   * @param from the node id
   * @param r the row
   */
  public BroadcastRouteRow(Credentials cred, NodeHandle from, RouteSet[] r) {
    super(addr, cred);

    fromNode = from;
    row = r;
    setPriority(0);
  }

  /**
   * Constructor.
   *
   * @param from the node id
   * @param r the row
   */
  public BroadcastRouteRow(NodeHandle from, RouteSet[] r) {
    super(addr);

    fromNode = from;
    row = r;
    setPriority(0);
  }

  /**
   * Gets the row that was sent in the message.
   *
   * @return the row.
   */
  public RouteSet[] getRow() {
    return row;
  }

  /**
   * Gets the from node.
   *
   * @return the from node.
   */
  public NodeHandle from() {
    return fromNode;
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @return DESCRIBE THE RETURN VALUE
   */
  public String toString() {
    String s = "";

    s += "BroadcastRouteRow(of " + fromNode.getNodeId() + ")";

    return s;
  }
}

==> FreePastry-2.0b2_20060905-source.tgz: pastry-2.0b2_20060905/src/rice/pastry/routing/BroadcastRouteRow.java <==
/*************************************************************************

"FreePastry" Peer-to-Peer Application Development Substrate 

Copyright 2002, Rice University. All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

- Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.

- Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

- Neither  the name  of Rice  University (RICE) nor  the names  of its
contributors may be  used to endorse or promote  products derived from
this software without specific prior written permission.

This software is provided by RICE and the contributors on an "as is"
basis, without any representations or warranties of any kind, express
or implied including, but not limited to, representations or
warranties of non-infringement, merchantability or fitness for a
particular purpose. In no event shall RICE or contributors be liable
for any direct, indirect, incidental, special, exemplary, or
consequential damages (including, but not limited to, procurement of
substitute goods or services; loss of use, data, or profits; or
business interruption) however caused and on any theory of liability,
whether in contract, strict liability, or tort (including negligence
or otherwise) arising in any way out of the use of this software, even
if advised of the possibility of such damage.

********************************************************************************/
package rice.pastry.routing;

import rice.p2p.commonapi.rawserialization.*;
import rice.pastry.*;
import rice.pastry.messaging.*;

import java.util.*;
import java.io.*;

/**
 * Broadcast message for a row from a routing table.
 *
 * @version $Id: BroadcastRouteRow.java 3353 2006-08-08 13:30:20Z jeffh $
 * @author Andrew Ladd
 */

public class BroadcastRouteRow extends PRawMessage implements Serializable {

  private NodeHandle fromNode;

  private RouteSet[] row;

  /**
   * DESCRIBE THE FIELD
   */
  public final static short TYPE = 2;


  /**
   * Constructor.
   *
   * @param stamp the timestamp
   * @param from the node id
   * @param r the row
   */
  public BroadcastRouteRow(Date stamp, NodeHandle from, RouteSet[] r) {
    super(RouteProtocolAddress.getCode(), stamp);
    fromNode = from;
    row = r;
    setPriority(MAX_PRIORITY);
  }

  /**
   * Constructor.
   *
   * @param from the node id
   * @param r the row
   */
  public BroadcastRouteRow(NodeHandle from, RouteSet[] r) {
    this(null, from, r);
  }

  /**
   * Constructor for BroadcastRouteRow.
   *
   * @param buf DESCRIBE THE PARAMETER
   * @param nhf DESCRIBE THE PARAMETER
   * @exception IOException DESCRIBE THE EXCEPTION
   */
  public BroadcastRouteRow(InputBuffer buf, NodeHandleFactory nhf) throws IOException {
    super(RouteProtocolAddress.getCode(), null);

    byte version = buf.readByte();
    switch (version) {
      case 0:
        fromNode = nhf.readNodeHandle(buf);
        row = new RouteSet[buf.readByte()];
        for (int i = 0; i < row.length; i++) {
          if (buf.readBoolean()) {
            row[i] = new RouteSet(buf, nhf);
          }
        }
        break;
      default:
        throw new IOException("Unknown Version: " + version);
    }
  }

  /**
   * Gets the row that was sent in the message.
   *
   * @return the row.
   */
  public RouteSet[] getRow() {
    return row;
  }

  /**
   * Raw Serialization **************************************
   *
   * @return The Type value
   */
  public short getType() {
    return TYPE;
  }

  /**
   * Gets the from node.
   *
   * @return the from node.
   */
  public NodeHandle from() {
    return fromNode;
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @return DESCRIBE THE RETURN VALUE
   */
  public String toString() {
    String s = "";

    s += "BroadcastRouteRow(of " + fromNode.getNodeId() + ")";

    return s;
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @return DESCRIBE THE RETURN VALUE
   */
  public String toStringFull() {
    String s = "BRR{" + fromNode + "}:";
    for (int i = 0; i < row.length; i++) {
      s += row[i] + "|";
    }
    return s;
  }

  /**
   * DESCRIBE THE METHOD
   *
   * @param buf DESCRIBE THE PARAMETER
   * @exception IOException DESCRIBE THE EXCEPTION
   */
  public void serialize(OutputBuffer buf) throws IOException {
    buf.writeByte((byte) 0);
    // version
    fromNode.serialize(buf);
    buf.writeByte((byte) row.length);
    for (int i = 0; i < row.length; i++) {
      if (row[i] != null) {
        buf.writeBoolean(true);
        row[i].serialize(buf);
      } else {
        buf.writeBoolean(false);
      }
    }
  }
}
